<?php

namespace Drupal\ai_web_automation;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Automation Scenario entity.
 */
class AutomationScenarioAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\ai_web_automation\Entity\AutomationScenarioInterface $entity */
    
    // Check admin permission first.
    if ($account->hasPermission('administer ai web automation')) {
      return AccessResult::allowed()->cachePerPermissions();
    }

    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished automation scenarios');
        }
        return AccessResult::allowedIfHasPermission($account, 'view automation scenarios');

      case 'update':
        $access = AccessResult::allowedIfHasPermission($account, 'edit any automation scenarios');
        if (!$access->isAllowed() && $account->id() == $entity->getOwnerId()) {
          $access = $access->orIf(AccessResult::allowedIfHasPermission($account, 'edit own automation scenarios'));
        }
        return $access;

      case 'delete':
        $access = AccessResult::allowedIfHasPermission($account, 'delete any automation scenarios');
        if (!$access->isAllowed() && $account->id() == $entity->getOwnerId()) {
          $access = $access->orIf(AccessResult::allowedIfHasPermission($account, 'delete own automation scenarios'));
        }
        return $access;

      case 'execute':
        if (!$entity->isPublished()) {
          return AccessResult::forbidden()->addCacheableDependency($entity);
        }
        $access = AccessResult::allowedIfHasPermission($account, 'execute any automation scenarios');
        if (!$access->isAllowed() && $account->id() == $entity->getOwnerId()) {
          $access = $access->orIf(AccessResult::allowedIfHasPermission($account, 'execute own automation scenarios'));
        }
        return $access->addCacheableDependency($entity);
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'create automation scenarios');
  }

}