<?php

namespace Drupal\ai_web_automation;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Automation Scenario entities.
 */
class AutomationScenarioListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('ID');
    $header['name'] = $this->t('Name');
    $header['status'] = $this->t('Status');
    $header['executions'] = $this->t('Executions');
    $header['last_run'] = $this->t('Last Run');
    $header['owner'] = $this->t('Owner');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\ai_web_automation\Entity\AutomationScenario $entity */
    $row['id'] = $entity->id();
    $row['name'] = Link::createFromRoute(
      $entity->label(),
      'entity.automation_scenario.canonical',
      ['automation_scenario' => $entity->id()]
    );
    $row['status'] = $entity->isPublished() ? $this->t('Published') : $this->t('Unpublished');
    $row['executions'] = $entity->getExecutionCount();
    
    $last_execution = $entity->getLastExecutionTime();
    $row['last_run'] = $last_execution ? \Drupal::service('date.formatter')->format($last_execution, 'short') : $this->t('Never');
    
    $row['owner'] = $entity->getOwner() ? $entity->getOwner()->toLink() : $this->t('Anonymous');
    
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  protected function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);
    
    if ($entity->access('execute') && $entity->hasLinkTemplate('execute')) {
      $operations['execute'] = [
        'title' => $this->t('Execute'),
        'weight' => 15,
        'url' => $this->ensureDestination($entity->toUrl('execute')),
      ];
    }
    
    if ($entity->access('update') && $entity->hasLinkTemplate('builder')) {
      $operations['builder'] = [
        'title' => $this->t('Builder'),
        'weight' => 5,
        'url' => $this->ensureDestination($entity->toUrl('builder')),
      ];
    }
    
    return $operations;
  }

}