<?php

namespace Drupal\ai_web_automation\Commands;

use Drush\Commands\DrushCommands;
use Drupal\Core\Entity\EntityDefinitionUpdateManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Drush commands for AI Web Automation module.
 */
class AiWebAutomationCommands extends DrushCommands {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity definition update manager.
   *
   * @var \Drupal\Core\Entity\EntityDefinitionUpdateManagerInterface
   */
  protected $entityDefinitionUpdateManager;

  /**
   * Constructs a new AiWebAutomationCommands object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Entity\EntityDefinitionUpdateManagerInterface $entity_definition_update_manager
   *   The entity definition update manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, EntityDefinitionUpdateManagerInterface $entity_definition_update_manager) {
    parent::__construct();
    $this->entityTypeManager = $entity_type_manager;
    $this->entityDefinitionUpdateManager = $entity_definition_update_manager;
  }

  /**
   * Install the automation scenario entity type.
   *
   * @command ai_web_automation:install-entity
   * @aliases awai
   * @usage ai_web_automation:install-entity
   *   Install the automation scenario entity type and its fields.
   */
  public function installEntity() {
    try {
      // Get the entity type definition.
      $entity_type = $this->entityTypeManager->getDefinition('automation_scenario');
      
      // Install the entity type if it doesn't exist.
      if (!$this->entityDefinitionUpdateManager->getEntityType('automation_scenario')) {
        $this->entityDefinitionUpdateManager->installEntityType($entity_type);
        $this->logger()->success('Automation scenario entity type installed successfully.');
      } else {
        $this->logger()->notice('Automation scenario entity type already exists.');
      }
      
      // Install field storage definitions.
      $field_definitions = \Drupal::service('entity_field.manager')->getFieldStorageDefinitions('automation_scenario');
      foreach ($field_definitions as $field_name => $field_definition) {
        if (!$this->entityDefinitionUpdateManager->getFieldStorageDefinition($field_name, 'automation_scenario')) {
          $this->entityDefinitionUpdateManager->installFieldStorageDefinition($field_name, 'automation_scenario', 'ai_web_automation', $field_definition);
        }
      }
      
      $this->logger()->success('All field definitions installed successfully.');
      
    } catch (\Exception $e) {
      $this->logger()->error('Failed to install entity type: ' . $e->getMessage());
    }
  }

}