<?php

namespace Drupal\ai_web_automation\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Automation Scenario entities.
 */
interface AutomationScenarioInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface, EntityPublishedInterface {

  /**
   * Gets the Automation Scenario name.
   *
   * @return string
   *   Name of the Automation Scenario.
   */
  public function getName();

  /**
   * Sets the Automation Scenario name.
   *
   * @param string $name
   *   The Automation Scenario name.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setName($name);

  /**
   * Gets the Automation Scenario description.
   *
   * @return string
   *   Description of the Automation Scenario.
   */
  public function getDescription();

  /**
   * Sets the Automation Scenario description.
   *
   * @param string $description
   *   The Automation Scenario description.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setDescription($description);


  /**
   * Gets the Automation Scenario creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Automation Scenario.
   */
  public function getCreatedTime();

  /**
   * Sets the Automation Scenario creation timestamp.
   *
   * @param int $timestamp
   *   The Automation Scenario creation timestamp.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Gets the automation steps.
   *
   * @return array
   *   Array of step configurations.
   */
  public function getSteps();

  /**
   * Sets the automation steps.
   *
   * @param array $steps
   *   Array of step configurations.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setSteps(array $steps);

  /**
   * Gets the scenario variables.
   *
   * @return array
   *   Array of variables.
   */
  public function getVariables();

  /**
   * Sets the scenario variables.
   *
   * @param array $variables
   *   Array of variables.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setVariables(array $variables);

  /**
   * Gets the last execution time.
   *
   * @return int|null
   *   The last execution timestamp or NULL.
   */
  public function getLastExecutionTime();

  /**
   * Sets the last execution time.
   *
   * @param int $timestamp
   *   The execution timestamp.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setLastExecutionTime($timestamp);

  /**
   * Gets the execution count.
   *
   * @return int
   *   The number of times this scenario has been executed.
   */
  public function getExecutionCount();

  /**
   * Increments the execution count.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function incrementExecutionCount();

  /**
   * Gets the scheduled execution time.
   *
   * @return int|null
   *   The scheduled timestamp or NULL.
   */
  public function getScheduledTime();

  /**
   * Sets the scheduled execution time.
   *
   * @param int|null $timestamp
   *   The scheduled timestamp or NULL to unschedule.
   *
   * @return \Drupal\ai_web_automation\Entity\AutomationScenarioInterface
   *   The called Automation Scenario entity.
   */
  public function setScheduledTime($timestamp);

}